using System;

namespace StefanWalter.Moss2010.PictureComments.SWPictureComments
{
	/// <summary>
	/// This class handles events raised during feature activation, deactivation, installation, uninstallation, and upgrade.
	/// </summary>
	/// <remarks>
	/// The GUID attached to this class may be used during packaging and should not be modified.
	/// </remarks>

	[System.Runtime.InteropServices.Guid("672a46e2-f747-45f3-9347-479e8c3163ff")]
	public class SWPictureCommentsEventReceiver : Microsoft.SharePoint.SPFeatureReceiver
	{
		private Logger MyLogger = new Logger(Constants.EventlogSource, Constants.EventlogLog, "FeatureReceiver");
		
		// Uncomment the method below to handle the event raised after a feature has been activated.

		public override void FeatureActivated(Microsoft.SharePoint.SPFeatureReceiverProperties properties)
		{
			this.MyLogger.WriteMethodStart("FeatureReceiver:FeatureActivated", properties);

			try 
			{
				Microsoft.SharePoint.SPWeb CurrentWeb = GetCurrentSite(properties);
				Microsoft.SharePoint.SPList CommentsList = CurrentWeb.Lists.TryGetList(Constants.ListCommentsTitle);

				if (CommentsList == null)
				{ 
					// create new comments-list
					Guid ListId = CurrentWeb.Lists.Add(Constants.ListCommentsTitle, Constants.ListCommentsDescription,
													   Microsoft.SharePoint.SPListTemplateType.GenericList);
					Microsoft.SharePoint.SPList NewList = CurrentWeb.Lists.GetList(ListId, false);

					NewList.OnQuickLaunch = false;
					NewList.Fields.Add(Constants.FieldNoteTitle, Microsoft.SharePoint.SPFieldType.Note, true);
					NewList.Fields.Add(Constants.FieldItemGUIDTitle, Microsoft.SharePoint.SPFieldType.Guid, true);
					NewList.Update(false);				
				}
			}
			catch (Microsoft.SharePoint.SPException Ex)
			{
				this.MyLogger.WriteWarningEntry(Ex.Message);
			}

			this.MyLogger.WriteMethodEnd("FeatureReceiver:FeatureActivated");
		}

		/// <summary>
		/// returns the corresponding SPWeb object
		/// </summary>
		/// <param name="properties">reciever properties</param>
		/// <returns>SPWeb object</returns>
		public Microsoft.SharePoint.SPWeb GetCurrentSite(Microsoft.SharePoint.SPFeatureReceiverProperties properties)
		{
			if (properties.Feature.Parent is Microsoft.SharePoint.SPWeb)
			{
				return properties.Feature.Parent as Microsoft.SharePoint.SPWeb;
			}
			else if (properties.Feature.Parent is Microsoft.SharePoint.SPSite)
			{
				return ((Microsoft.SharePoint.SPSite)properties.Feature.Parent).RootWeb;
			}

			return null;
		}

		// Uncomment the method below to handle the event raised before a feature is deactivated.

		//public override void FeatureDeactivating(SPFeatureReceiverProperties properties)
		//{
		//}


		// Uncomment the method below to handle the event raised after a feature has been installed.

		//public override void FeatureInstalled(SPFeatureReceiverProperties properties)
		//{
		//}


		// Uncomment the method below to handle the event raised before a feature is uninstalled.

		//public override void FeatureUninstalling(SPFeatureReceiverProperties properties)
		//{
		//}

		// Uncomment the method below to handle the event raised when a feature is upgrading.

		//public override void FeatureUpgrading(SPFeatureReceiverProperties properties, string upgradeActionName, System.Collections.Generic.IDictionary<string, string> parameters)
		//{
		//}
	}
}
