using System;

namespace StefanWalter.Moss2010.PictureComments
{
    /// <summary>
    /// code behind class for CustomPictureLibraryAction.aspx
    /// </summary>
    public partial class CustomPictureLibraryAction : Microsoft.SharePoint.WebPartPages.WebPartPage
    {
        # region variable declaration
        private int MyCurrentItemId;
        private Guid MyListId;
        private string MySiteRelativeUrl;
        private Logger MyLogger = new Logger(Constants.EventlogSource, Constants.EventlogLog, "CustomPictureLibraryAction");
        private bool MyResetFlag = false;

        // aspx controls
		protected System.Web.UI.WebControls.Literal litImage = new System.Web.UI.WebControls.Literal();
		protected System.Web.UI.WebControls.Literal litNumber = new System.Web.UI.WebControls.Literal();
		protected System.Web.UI.WebControls.Literal litNameTitle = new System.Web.UI.WebControls.Literal();
		protected System.Web.UI.WebControls.Literal litNameValue = new System.Web.UI.WebControls.Literal();
		protected System.Web.UI.WebControls.Literal litDateTitle = new System.Web.UI.WebControls.Literal();
		protected System.Web.UI.WebControls.Literal litDateValue = new System.Web.UI.WebControls.Literal();
		protected System.Web.UI.WebControls.Literal litDescriptionTitle = new System.Web.UI.WebControls.Literal();
		protected System.Web.UI.WebControls.Literal litDescriptionValue = new System.Web.UI.WebControls.Literal();
		protected System.Web.UI.WebControls.Literal litCommentTitle = new System.Web.UI.WebControls.Literal();
		protected System.Web.UI.WebControls.Literal litAvailableComments = new System.Web.UI.WebControls.Literal();
		protected System.Web.UI.WebControls.Literal litDeleteImages = new System.Web.UI.WebControls.Literal();
		protected System.Web.UI.WebControls.Literal litSiteMapPlace = new System.Web.UI.WebControls.Literal();
		protected System.Web.UI.WebControls.Literal litListPropertyPlace = new System.Web.UI.WebControls.Literal();
		protected System.Web.UI.WebControls.TextBox txtComment = new System.Web.UI.WebControls.TextBox();
		protected System.Web.UI.WebControls.ImageButton imbNext = new System.Web.UI.WebControls.ImageButton();
		protected System.Web.UI.WebControls.ImageButton imbPrev = new System.Web.UI.WebControls.ImageButton();
		protected System.Web.UI.WebControls.Button btnOk = new System.Web.UI.WebControls.Button();
		protected System.Web.UI.WebControls.Button btnCancel = new System.Web.UI.WebControls.Button();
        protected System.Web.UI.WebControls.Panel pnlCommentRows = new System.Web.UI.WebControls.Panel();
        # endregion variable declaration

        /// <summary>
        /// OnInit
        /// </summary>
        /// <param name="e"></param>
        protected override void OnInit(EventArgs e)
        {
            this.Page.RegisterRequiresControlState(this);
        }

        /// <summary>
        /// Page_Load
        /// </summary>
        /// <param name="sender">senderobject</param>
        /// <param name="e">eventargs</param>
        protected void Page_Load(object sender, EventArgs e)
        {
			try
			{
				// reset controls
				if (!this.IsPostBack || this.MyResetFlag)
				{
					this.ResetControls();
				}

				#region readQueryString

				this.MySiteRelativeUrl = this.GetQueryString(Constants.QSPSiteUrl);

				if (!string.IsNullOrEmpty(this.GetQueryString(Constants.QSPListId)))
				{
					this.MyListId = new Guid(this.GetQueryString(Constants.QSPListId));
				}

				if (!string.IsNullOrEmpty(this.GetQueryString(Constants.QSPItemId)))
				{
					this.MyCurrentItemId = Convert.ToInt16(this.GetQueryString(Constants.QSPItemId));
				}
				else
				{
					this.MyCurrentItemId = 0;
				}
				#endregion readQueryString

				using (Microsoft.SharePoint.SPSite CurrentSite = new Microsoft.SharePoint.SPSite(this.MySiteRelativeUrl))
				{
					CurrentSite.CatchAccessDeniedException = false;
					using (Microsoft.SharePoint.SPWeb CurrentWeb = CurrentSite.OpenWeb(GetWebUrl(CurrentSite)))
					{
						if (CurrentWeb.Exists)
						{
							this.litSiteMapPlace.Text = this.Request.QueryString[Constants.QSPSiteUrl];
							this.litListPropertyPlace.Text = CurrentWeb.Lists.GetList(this.MyListId, false).Title;

							// delete comment command
							if (!string.IsNullOrEmpty(this.Request.QueryString[Constants.QSPDeleteCommand]))
							{
								try
								{
									CurrentWeb.AllowUnsafeUpdates = true;
									Microsoft.SharePoint.SPList CurrentList = CurrentWeb.Lists[Constants.ListCommentsTitle];
									CurrentList.Items[new Guid(this.Request.QueryString[Constants.QSPDeleteCommand])].Delete();
									CurrentList.Update();
									this.pnlCommentRows.Controls.Clear();
									CurrentWeb.AllowUnsafeUpdates = false;
								}
								catch (Exception Ex)
								{
									this.MyLogger.WriteErrorEntry("DeleteComment: " + Ex.Message);
								}
							}

							// check image dimensions and resize if neccessary
							bool LibraryHasPictures = false;
							System.Text.StringBuilder ImageString = new System.Text.StringBuilder();
							if (CurrentWeb.Lists.GetList(this.MyListId, false).Items.Count > 0)
							{
								LibraryHasPictures = true;
								System.Drawing.Image UploadedImage = System.Drawing.Image.FromStream(CurrentWeb.Lists.GetList(this.MyListId, false).Items[this.MyCurrentItemId].File.OpenBinaryStream());
								float UploadedImageWidth = UploadedImage.PhysicalDimension.Width;
								float UploadedImageHeight = UploadedImage.PhysicalDimension.Height;
								float MaxWidth = 500, MaxHeight = 500;

								if (UploadedImageWidth > 500 || UploadedImageHeight > 500)
								{
									float Ratio = (float)UploadedImageWidth / UploadedImageHeight;
									UploadedImageWidth = MaxWidth;
									UploadedImageHeight = (int)Math.Floor(MaxWidth / Ratio);

									if (UploadedImageHeight > MaxHeight)
									{
										UploadedImageHeight = MaxHeight;
										UploadedImageWidth = (float)Math.Floor(MaxHeight * Ratio);
									}
								}

								// create image htmlcode
								ImageString.Append("<table CELLPADDING=0 CELLSPACING=0 BORDER=0 WIDTH=\"500px\" HEIGHT=\"500px\">");
								ImageString.Append("<tr height=100% valign=middle><td height=\"500px\" width=\"500px\" align=\"center\" valign=middle>");
								ImageString.Append("<IMG style=\"BORDER-RIGHT: 0px solid; BORDER-TOP: 0px solid; BORDER-LEFT: 0px solid; ");
								ImageString.Append("BORDER-BOTTOM: 0px solid; WIDTH=" + UploadedImageWidth + "; HEIGHT=" +
										  UploadedImageHeight + "\" src=\"" + CurrentWeb.Lists.GetList(this.MyListId, false).ParentWeb.Url +
										  "/" + CurrentWeb.Lists.GetList(this.MyListId, false).Items[this.MyCurrentItemId].File.Url +
										  "\" border=0></td></tr></table>");
							}
							else
							{
								ImageString.Append("<table CELLPADDING=0 CELLSPACING=0 BORDER=0 WIDTH=\"500px\" HEIGHT=\"500px\">");
								ImageString.Append("<tr height=100% valign=middle><td height=\"500px\" width=\"500px\" align=\"center\" valign=middle><div Style=\"font-family: Verdana; font-size: 12pt\">");
								ImageString.Append(GetLocalizedValue("PopUpWindow_NoImageThere") + "</div></td></tr></table>");
								this.MyCurrentItemId = -1;
							}

							this.litImage.Text = ImageString.ToString();

							// window title
							this.Title = GetLocalizedValue("PopUpWindow_Title");

							string ImageXFromY_1 = GetLocalizedValue("PopUpWindow_ImageXFromY_1");
							string ImageXFromY_2 = GetLocalizedValue("PopUpWindow_ImageXFromY_2");

							// set literal controls
							this.litNumber.Text = ImageXFromY_1 + ": " + (this.MyCurrentItemId + 1).ToString() + " " + ImageXFromY_2 + " " + CurrentWeb.Lists.GetList(this.MyListId, false).Items.Count;
							this.litNameValue.Text = GetFieldValue(CurrentWeb, Microsoft.SharePoint.SPBuiltInFieldId.Title);
							this.litDateValue.Text = GetFieldValue(CurrentWeb, Microsoft.SharePoint.SPBuiltInFieldId.Created);
							this.litDescriptionValue.Text = GetFieldValue(CurrentWeb, Constants.FieldDescriptionName);

							this.txtComment.Style.Add("width", "100%");

							if (!LibraryHasPictures || !CheckUserPermission(CurrentWeb.Site.ID, CurrentWeb.ID, CurrentWeb.Lists[Constants.ListCommentsTitle].ID, CurrentWeb.CurrentUser.UserToken))
							{
								this.btnOk.Enabled = false;
								this.btnCancel.Enabled = false;
							}

							// set imagebuttons
							this.imbNext.ImageUrl = "~/_layouts/images/plnext1.gif";
							this.imbPrev.ImageUrl = "~/_layouts/images/plprev1.gif";
							if (!LibraryHasPictures || CurrentWeb.Lists.GetList(MyListId, false).ItemCount < 2)
							{
								this.imbNext.Visible = false;
								this.imbPrev.Visible = false;
							}
							else
							{
								this.imbNext.Attributes["OnMouseOver"] = "javascript:EvImageOverChange(this, '" + CurrentWeb.Lists.GetList(this.MyListId, false).ParentWeb.Url + "/_layouts/images/plnext2.gif" + "');";
								this.imbNext.Attributes["OnMouseOut"] = "javascript:EvImageOverChange(this, '" + CurrentWeb.Lists.GetList(this.MyListId, false).ParentWeb.Url + "/_layouts/images/plnext1.gif" + "');";
								this.imbPrev.Attributes["OnMouseOver"] = "javascript:EvImageOverChange(this, '" + CurrentWeb.Lists.GetList(this.MyListId, false).ParentWeb.Url + "/_layouts/images/plprev2.gif" + "');";
								this.imbPrev.Attributes["OnMouseOut"] = "javascript:EvImageOverChange(this, '" + CurrentWeb.Lists.GetList(this.MyListId, false).ParentWeb.Url + "/_layouts/images/plprev1.gif" + "');";
							}

							// load comments
							this.GetComments(CurrentWeb);
						}
					}
				}
			}
			catch (Exception Ex)
			{
				this.MyLogger.WriteErrorEntry("Page_Load: " + Ex.Message);
				this.imbNext.Visible = false;
				this.imbPrev.Visible = false;
				this.btnOk.Enabled = false;
				this.btnCancel.Enabled = false;

				System.Text.StringBuilder ImageString = new System.Text.StringBuilder();
				ImageString.Append("<table CELLPADDING=0 CELLSPACING=0 BORDER=0 WIDTH=\"500px\" HEIGHT=\"500px\">");
				ImageString.Append("<tr height=100% valign=middle><td height=\"500px\" width=\"500px\" align=\"center\" valign=middle><div Style=\"font-family: Verdana; font-size: 12pt\">");
				ImageString.Append(GetLocalizedValue("PopUpWindow_Error") + "</div></td></tr></table>");
				this.litImage.Text = ImageString.ToString();
			}
			finally
			{
				this.litNameTitle.Text = GetLocalizedValue("PopUpWindow_ImageName");
				this.litCommentTitle.Text = GetLocalizedValue("PopUpWindow_ImageAddComment");
				this.litDateTitle.Text = GetLocalizedValue("PopUpWindow_ImageDate");
				this.litDescriptionTitle.Text = GetLocalizedValue("PopUpWindow_ImageDescription");			
			}
        }

		/// <summary>
		/// Returns the right Url
		/// </summary>
		/// <param name="currentSite">Site</param>
		/// <returns>Weburl</returns>
		private string GetWebUrl(Microsoft.SharePoint.SPSite currentSite)
		{
			string WebUrl = string.Empty;
			if (currentSite.RootWeb.Url != this.MySiteRelativeUrl)
			{
				WebUrl = this.MySiteRelativeUrl.Replace(currentSite.Url, "").Substring(1);
			}

			return WebUrl;
		}

		/// <summary>
		/// Checks user permissions to write / delete into lists
		/// </summary>
		/// <param name="theGuidOfTheSite">site guid</param>
		/// <param name="theGuidOfTheWeb">web guid</param>
		/// <param name="theGuidOfTheList">list guid</param>
		/// <param name="theSPUserToken">loggedin usertoken</param>
		/// <returns></returns>
		private bool CheckUserPermission(Guid theGuidOfTheSite, Guid theGuidOfTheWeb, Guid theGuidOfTheList, Microsoft.SharePoint.SPUserToken theSPUserToken)
        {
            Microsoft.SharePoint.Administration.SPUrlZone theSavedZone = Microsoft.SharePoint.SPContext.Current.Site.Zone;
			Microsoft.SharePoint.SPSite site = new Microsoft.SharePoint.SPSite(theGuidOfTheSite, theSavedZone, theSPUserToken);
            site.CatchAccessDeniedException = false;

			using (Microsoft.SharePoint.SPWeb web = site.OpenWeb(theGuidOfTheWeb))
            {
                if (web.Lists[theGuidOfTheList].DoesUserHavePermissions(Microsoft.SharePoint.SPBasePermissions.DeleteListItems))
                {
                    return true;
                }
                else
                {
                    return false;
                }
            }
        }

		/// <summary>
		/// reads localized values
		/// </summary>
		/// <param name="key">key</param>
		/// <returns>value</returns>
        private string GetLocalizedValue(string key)
        {
            // localizing
            uint LanguageId = (uint)System.Threading.Thread.CurrentThread.CurrentUICulture.LCID;
            return Microsoft.SharePoint.Utilities.SPUtility.GetLocalizedString("$Resources:" + key, "SWPictureComments", LanguageId);
        }

        /// <summary>
        /// resets aspx controls
        /// </summary>
        private void ResetControls()
        { 
            this.litImage.Text = string.Empty;
            this.litNumber.Text = string.Empty;
            this.litNameTitle.Text = string.Empty;
            this.litNameValue.Text = string.Empty;
            this.litDateTitle.Text = string.Empty;
            this.litDateValue.Text = string.Empty;
            this.litDescriptionTitle.Text = string.Empty;
            this.litDescriptionValue.Text = string.Empty;
            this.litCommentTitle.Text = string.Empty;
            this.litAvailableComments.Text = string.Empty;
            this.litDeleteImages.Text = string.Empty;
            this.litSiteMapPlace.Text = string.Empty;
            this.litListPropertyPlace.Text = string.Empty;
            this.txtComment.Text = string.Empty;
            this.imbNext.Visible = true;
            this.imbPrev.Visible = true;
            this.btnOk.Enabled = true;
            this.btnCancel.Enabled = true;
            this.pnlCommentRows.Controls.Clear();        
        }

        /// <summary>
        /// loads comments for the picture
        /// </summary>
        /// <param name="currentSite">webobject</param>
		private void GetComments(Microsoft.SharePoint.SPWeb currentSite)
        {
            try
            {
				Microsoft.SharePoint.SPList CurrentList;
                CurrentList = currentSite.Lists[Constants.ListCommentsTitle];

                // CAML query
				Microsoft.SharePoint.SPQuery Query = new Microsoft.SharePoint.SPQuery();
                string Caml = "<Where><And><Eq><FieldRef Name=\"Title\" /><Value Type=\"Text\">" + 
                              currentSite.Lists.GetList(this.MyListId, false).ID.ToString() + "</Value></Eq>" +
                              "<Eq><FieldRef Name=\"ItemGUID\" /><Value Type=\"Guid\">" + 
                              currentSite.Lists.GetList(this.MyListId, false).Items[this.MyCurrentItemId].UniqueId + "</Value></Eq></And></Where>";

                Query.Query = Caml;
				Microsoft.SharePoint.SPListItemCollection CurrentListItems = CurrentList.GetItems(Query);

                System.Text.StringBuilder CommentsBuilder = new System.Text.StringBuilder();
                System.Web.UI.WebControls.Literal CommentRow = new System.Web.UI.WebControls.Literal();

                int ItemCounter = 0;
				foreach (Microsoft.SharePoint.SPListItem CurrentItem in CurrentListItems)
                {
                    ItemCounter++;
					Microsoft.SharePoint.SPFieldUser CreatedFrom = (Microsoft.SharePoint.SPFieldUser)CurrentItem.Fields[Microsoft.SharePoint.SPBuiltInFieldId.Author];
					Microsoft.SharePoint.SPFieldUserValue User = (Microsoft.SharePoint.SPFieldUserValue)CreatedFrom.GetFieldValue(CurrentItem[Microsoft.SharePoint.SPBuiltInFieldId.Author].ToString());

                    string DeleteLink = string.Empty;
					Microsoft.SharePoint.SPUser CurrentUser = currentSite.CurrentUser;
                    
                    // display deletebutton only when author = logged in user
                    if (CurrentUser.LoginName == User.User.LoginName)
                    {
                        string Path = GetPath(CurrentItem.UniqueId.ToString());
                        DeleteLink = "<a title=\"" + GetLocalizedValue("PopUpWindow_Delete") + "\" href=\"" + Path + "\"><img border=\"0\" src=\"" + currentSite.Lists.GetList(this.MyListId, false).ParentWeb.Url + "/_layouts/images/delete.gif\"></a>";
                    }
                    else
                    {
                        DeleteLink = string.Empty;
                    }

                    // HTML comment table
                    CommentsBuilder.Append("<table border=0 cellspacing=0 cellpadding=0 width=100%><tr><td width=100%><div id=\"comments\"><div Style=\"font-family: Verdana; font-size: 8pt\">");
					CommentsBuilder.Append("<b>" + GetLocalizedValue("PopUpWindow_CommentNr") + ItemCounter + "</b> (" + User.User.Name + ", " + CurrentItem[Microsoft.SharePoint.SPBuiltInFieldId.Created] + ")");
                    CommentsBuilder.Append("<br><br>" + GetListItemValue(CurrentItem, Constants.FieldNoteTitle));
                    CommentsBuilder.Append("</div></td><td valign=top>" + DeleteLink + "</td></tr></table><br>");
                }

                CommentRow.Text = CommentsBuilder.ToString();
                this.pnlCommentRows.Controls.Add(CommentRow);
            }
            catch (Exception Ex)
            {
                this.MyLogger.WriteErrorEntry("GetComments: " + Ex.Message);
            }
        }

        /// <summary>
        /// returns path for redirect
        /// </summary>
        /// <param name="commentDelete">GUID as string from listitem</param>
        /// <returns>path</returns>
        private string GetPath(string commentDelete)
        {
            string Url = this.Request.Url.OriginalString.Substring(0, this.Request.Url.OriginalString.Length - (this.Request.Url.OriginalString.Length - this.Request.Url.OriginalString.IndexOf('?')));
            string SiteUrl = this.GetQueryString(Constants.QSPSiteUrl);
            string ListId = this.GetQueryString(Constants.QSPListId);

            string Path = Url + "?" + Constants.QSPSiteUrl + "=" + SiteUrl +
                                "&" + Constants.QSPListId + "=" + ListId +
                                "&" + Constants.QSPItemId + "=" + this.MyCurrentItemId +
                                "&" + Constants.QSPDeleteCommand + "=" + commentDelete;            
            
            return Path;
        }

        /// <summary>
        /// returns the value from querystring
        /// </summary>
        /// <param name="key">key</param>
        /// <returns></returns>
        private string GetQueryString(string key)
        {
            return this.GetQueryString(key, false);
        }

        /// <summary>
        /// returns the value from querystring
        /// </summary>
        /// <param name="key">key</param>
        /// <param name="mandatory">mandatory parameter</param>
        /// <returns></returns>
        private string GetQueryString(string key, bool mandatory)
        {
            if (string.IsNullOrEmpty(this.Request.QueryString[key]))
            {
                if (mandatory)
                {
                    this.MyLogger.WriteErrorEntry("GetQueryString = null, key=" + key);
                }

                return string.Empty;
            }
            else 
            {
                return this.Request.QueryString[key];
            }
        }

        /// <summary>
        /// returns a string value from an listitemfield
        /// </summary>
        /// <param name="currentItem">listitem</param>
        /// <param name="fieldName">fieldname</param>
        /// <returns></returns>
		private string GetListItemValue(Microsoft.SharePoint.SPListItem currentItem, string fieldName)
        {
            string fieldValue = string.Empty;

            try
            {
                fieldValue = currentItem[fieldName].ToString();
            }
            catch
            { 
            }

            return fieldValue;
        }

        /// <summary>
        /// returns a string value from an listitemfield OR an 'nothing there' message
        /// </summary>
        /// <param name="currentWeb"></param>
        /// <param name="internalName"></param>
        /// <returns></returns>
		private string GetFieldValue(Microsoft.SharePoint.SPWeb currentWeb, object internalKey)
        {
            string FieldValue = "&lt;" + GetLocalizedValue("PopUpWindow_NoComments") + "&gt;";

            try
            {
				Microsoft.SharePoint.SPListItem CurrentItem = currentWeb.Lists.GetList(this.MyListId, false).Items[this.MyCurrentItemId];
                if (internalKey.GetType() == typeof(string))
                {
                    if(CurrentItem.Fields.ContainsField((string)internalKey) && CurrentItem[(string)internalKey] != null)
                    {
                        FieldValue = CurrentItem[(string)internalKey].ToString();
                    }
                }
                else
                {
                    FieldValue = CurrentItem[(Guid)internalKey].ToString();
                }
            }
            catch
            {
            }

            return FieldValue;
        }

        /// <summary>
        /// shows the next picture
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        public void imbNext_OnClick(object sender, EventArgs e)
        {
            try
            {
				using (Microsoft.SharePoint.SPSite CurrentSite = new Microsoft.SharePoint.SPSite(this.MySiteRelativeUrl))
				{
					CurrentSite.CatchAccessDeniedException = false;
					using (Microsoft.SharePoint.SPWeb CurrentWeb = CurrentSite.OpenWeb(GetWebUrl(CurrentSite)))
					{
						if (this.MyCurrentItemId == CurrentWeb.Lists.GetList(this.MyListId, false).Items.Count - 1)
						{
							this.MyCurrentItemId = 0;
						}
						else
						{
							this.MyCurrentItemId++;
						}
					}
				}
            }
            catch (Exception Ex)
            {
                this.MyLogger.WriteErrorEntry("imbNext_OnClick: " + Ex.Message);
            }

            this.RedirectMe();
        }

        /// <summary>
        /// shows the picture before
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        public void imbPrev_OnClick(object sender, EventArgs e)
        {
            try
            {
				using (Microsoft.SharePoint.SPSite CurrentSite = new Microsoft.SharePoint.SPSite(this.MySiteRelativeUrl))
				{
					CurrentSite.CatchAccessDeniedException = false;
					using (Microsoft.SharePoint.SPWeb CurrentWeb = CurrentSite.OpenWeb(GetWebUrl(CurrentSite)))
					{
						if (this.MyCurrentItemId == 0)
						{
							this.MyCurrentItemId = CurrentWeb.Lists.GetList(this.MyListId, false).Items.Count - 1;
						}
						else
						{
							this.MyCurrentItemId--;
						}
					}
				}
            }
            catch (Exception Ex)
            {
                this.MyLogger.WriteErrorEntry("imbPrev_OnClick: " + Ex.Message); 
            }

            this.RedirectMe();
        }

        /// <summary>
        /// saves a new comment
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        public void btnSave_Click(object sender, EventArgs e)
        {
            try
            {
				using (Microsoft.SharePoint.SPSite CurrentSite = new Microsoft.SharePoint.SPSite(this.MySiteRelativeUrl))
				{
					CurrentSite.CatchAccessDeniedException = false;
					using (Microsoft.SharePoint.SPWeb CurrentWeb = CurrentSite.OpenWeb(GetWebUrl(CurrentSite)))
					{
						CurrentWeb.AllowUnsafeUpdates = true;
						Microsoft.SharePoint.SPList CurrentList = CurrentWeb.Lists[Constants.ListCommentsTitle];
						Microsoft.SharePoint.SPListItem NewItem = CurrentList.Items.Add();

						NewItem[Microsoft.SharePoint.SPBuiltInFieldId.Title] = CurrentWeb.Lists.GetList(this.MyListId, false).ID.ToString();
						NewItem[Constants.FieldItemGUIDTitle] = CurrentWeb.Lists.GetList(this.MyListId, false).Items[this.MyCurrentItemId].UniqueId;
						NewItem[Constants.FieldNoteTitle] = this.txtComment.Text;
						NewItem.Update();
						CurrentWeb.AllowUnsafeUpdates = false;

						// reload the page
						this.RedirectMe();
					}
                }
            }
            catch (Exception Ex)
            {
                this.MyLogger.WriteErrorEntry("btnSave_Click: " + Ex.Message); 
            }            
        }

        /// <summary>
        /// cancels the comment
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        public void btnCancel_Click(object sender, EventArgs e)
        {
            this.RedirectMe();
        }

        /// <summary>
        /// redirect with new parameters
        /// </summary>
        private void RedirectMe()
        {
            this.MyResetFlag = false;
            string Path = this.GetPath(string.Empty);
            Microsoft.SharePoint.Utilities.SPUtility.Redirect(Path, Microsoft.SharePoint.Utilities.SPRedirectFlags.UseSource, System.Web.HttpContext.Current);
        }

        #region controlstate
        protected override void LoadControlState(object savedState)
        {
            object[] StateBag = (object[])savedState;
            base.LoadControlState(StateBag[0]);
            if (StateBag[1] != null)
            {
                this.MyResetFlag = Convert.ToBoolean(StateBag[1]);
            }
        }

        protected override object SaveControlState()
        {
            object[] Statebag = new object[2];
            Statebag[0] = base.SaveControlState();
            Statebag[1] = this.MyResetFlag;

            return Statebag;
        }
        #endregion controlstate
    }
}
