﻿using System;

namespace StefanWalter.Moss2010.PictureComments
{
	/// <summary>
	/// this class represents the eventlogger object
	/// </summary>
	public class Logger
	{
		private string MySource;
		private string MyClassName;

		/// <summary>
		/// logger contructor
		/// </summary>
		/// <param name="source">eventlog source</param>
		/// <param name="log">eventsource logname</param>
		/// <param name="className">classname</param>
		public Logger(string source, string log, string className)
		{
			this.MySource = source;
			this.MyClassName = className;

			try
			{
				if (!System.Diagnostics.EventLog.SourceExists(this.MySource))
				{
					System.Diagnostics.EventLog.CreateEventSource(this.MySource, log);
				}
			}
			catch
			{
			}
		}

		/// <summary>
		/// create entries from type 'Information'
		/// </summary>
		/// <param name="message">entry</param>
		public void WriteInformationEntry(string message)
		{
			try
			{
				System.Diagnostics.EventLog.WriteEntry(this.MySource, this.MyClassName + ", " + message, System.Diagnostics.EventLogEntryType.Information);
			}
			catch
			{
			}
		}

		/// <summary>
		/// create entries from type 'Warning'
		/// </summary>
		/// <param name="message">entry</param>
		public void WriteWarningEntry(string message)
		{
			try
			{
				System.Diagnostics.EventLog.WriteEntry(this.MySource, this.MyClassName + ", " + message, System.Diagnostics.EventLogEntryType.Warning);
			}
			catch
			{
			}
		}

		/// <summary>
		/// create entries from type 'Error'
		/// </summary>
		/// <param name="message">entry</param>
		public void WriteErrorEntry(string message)
		{
			try
			{
				System.Diagnostics.EventLog.WriteEntry(this.MySource, this.MyClassName + ", " + message, System.Diagnostics.EventLogEntryType.Error);
			}
			catch
			{
			}
		}

		/// <summary>
		/// create methodstart entries
		/// </summary>
		/// <param name="methodName">entry</param>
		/// <param name="args">paremeters</param>
		public void WriteMethodStart(string methodName, params object[] args)
		{
			System.Text.StringBuilder data = new System.Text.StringBuilder("StartMethod: " + methodName);

			if (args != null)
			{
				for (int i = 0; i == args.Length; i++)
				{
					if (i == 0)
					{
						data.Append(": " + args[i]);
					}
					else
					{
						data.Append(", " + args[i]);
					}
				}
			}

			WriteInformationEntry(data.ToString());
		}

		/// <summary>
		/// create methodend entries
		/// </summary>
		/// <param name="methodName">name of the method</param>
		public void WriteMethodEnd(string methodName)
		{
			WriteInformationEntry("EndMethod: " + methodName);
		}
	}
}
